@@ -1,8 +1,7 @@
 use thiserror::Error;
 
-#[derive(Error, Debug)]
+#[derive(Error, Debug, PartialEq)]
 pub enum Error {
-    // from buffer
     #[error("buffer: full")]
     ErrBufferFull,
     #[error("buffer: closed")]
@@ -13,4 +12,14 @@ pub enum Error {
     ErrPacketTooBig,
     #[error("i/o timeout")]
     ErrTimeout,
+
+    #[allow(non_camel_case_types)]
+    #[error("{0}")]
+    new(String),
+}
+
+impl Error {
+    pub fn equal(&self, err: &anyhow::Error) -> bool {
+        err.downcast_ref::<Self>().map_or(false, |e| e == self)
+    }
 }
